recsyslearn package
===================

Submodules
----------

recsyslearn.errors module
-------------------------

.. automodule:: recsyslearn.errors
    :members:
    :undoc-members:
    :show-inheritance:

recsyslearn.metrics module
--------------------------

.. automodule:: recsyslearn.metrics
    :members:
    :undoc-members:
    :show-inheritance:

recsyslearn.segmentations module
--------------------------------

.. automodule:: recsyslearn.segmentations
    :members:
    :undoc-members:
    :show-inheritance:

recsyslearn.utils module
------------------------

.. automodule:: recsyslearn.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: recsyslearn
    :members:
    :undoc-members:
    :show-inheritance:
